.. :changelog:

History
-------

0.2.0 (2018-08-08)
++++++++++++++++++

* Support for Django 2.1

0.1.3 (2018-06-21)
++++++++++++++++++

* Move dependency back to official django-taggit-serializer package now that our pull request has been merged.

0.1.0 (2018-04-07)
++++++++++++++++++

* First release on PyPI.
